<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimVertical</name>
    <message>
        <location filename="../DimVerticalInit.js" line="+2"/>
        <source>&amp;Vertical</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Pionowa
Ograniczenie &amp;pionowo</translatorcomment>
        <translation>P&amp;ionowy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw vertical dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje wymiar pionowy</translation>
    </message>
</context>
</TS>
